@@ -1,11 +1,12 @@
-__version__ = "3.1.1"
+__version__ = "4.0.0"
 
 from .load import (
     load as load,
     loads as loads,
     load_dir as load_dir,
     load_bq as load_bq,
-    read_schema_file as read_schema_file
+    read_schema_file as read_schema_file,
+    from_schema as from_schema
 )
 from .table import (
     Table as Table,
